@@ -24,4 +24,4 @@ This file simply redirects to the ``nr.c4d.dev`` main module.
 
 from nr.c4d.dev.__main__ import main
 if __name__ == "__main__":
-    main()
+    main('c4ddev.py')
